<template>
  <div class="card" :class="widgetClasses">
    <!--begin::Header-->
    <div class="card-header border-0 pt-5">
      <h3 class="card-title align-items-start flex-column">
        <span class="card-label fw-bolder fs-3 mb-1">
          {{ translate("chart.latest_invoices") }}
        </span>
      </h3>
      <h3 class="card-title align-items-start flex-column">
        <router-link
          to="/invoices/create"
          class="btn btn-sm btn-light-primary w-100"
          :class="[$i18n.locale == 'ar' ? 'hacen_algeria' : '']"
        >
          <i class="mdi mdi-plus-circle"></i>
          {{ $t("app.addNew") }}
        </router-link>
      </h3>
    </div>
    <!--end::Header-->
    <!--begin::Body-->
    <div class="card-body py-3">
      <div class="tab-content">
        <!--begin::Tap pane-->
        <div class="tab-pane fade active show" id="kt_table_widget_5_tab_1">
          <!--begin::Table container-->
          <div class="table-responsive">
            <!--begin::Table-->
            <table
              class="
                table table-row-dashed table-row-gray-200
                align-middle
                gs-0
                gy-4
              "
            >
              <!--begin::Table head-->
              <thead>
                <tr class="border-0">
                  <th class="p-0 w-50px"></th>
                  <th class="p-0 min-w-150px"></th>
                  <th class="p-0 min-w-140px"></th>
                  <th class="p-0 min-w-110px"></th>
                  <th class="p-0 min-w-110px"></th>
                  <th class="p-0 min-w-50px"></th>
                </tr>
              </thead>
              <!--end::Table head-->
              <!--begin::Table body-->
              <tbody>
                <tr v-for="(invoice, key) in invoices" :key="key">
                  <td>
                    <div class="symbol symbol-45px me-2">
                      <span class="symbol-label">
                        <img
                          :src="invoice.company.url"
                          class="h-50 align-self-center"
                          alt=""
                        />
                      </span>
                    </div>
                  </td>
                  <td>
                    <a
                      href="#"
                      class="text-dark fw-bolder text-hover-primary mb-1 fs-6"
                      >{{ invoice.user.name }}</a
                    >
                    <span class="text-muted fw-bold d-block">{{
                      invoice.user.email
                    }}</span>
                  </td>
                  <td class="text-end text-muted fw-bold">
                    {{ invoice.subject }}
                  </td>
                  <td class="text-end">
                    <span
                      :class="
                        'badge badge-light-' +
                        (invoice.payment_status == 'pending'
                          ? 'warning'
                          : 'success')
                      "
                    >
                      {{ $t("view." + invoice.payment_status) }}</span
                    >
                  </td>
                  <td class="text-end">
                    <span> {{ invoice.price }}</span>
                  </td>
                  <td class="text-end">
                    <button
                      type="button"
                      @click="
                        copyLink(
                          apiDomainName +
                            '/invoices/' +
                            invoice.encrypt_id +
                            '/quick-payment-link/' +
                            invoice.invoice_key
                        )
                      "
                      class="
                        btn
                        btn-bg-light
                        btn-color-muted
                        btn-active-color-success
                        btn-sm
                      "
                      style="
                        width: 32px;
                        height: 32px;
                        padding: 5px 10px;
                        margin-right: 5px;
                      "
                    >
                      <i class="bx bx-link font-size-17"></i>
                    </button>
                  </td>
                </tr>
              </tbody>
              <!--end::Table body-->
            </table>
          </div>
          <!--end::Table-->
        </div>
        <!--end::Tap pane-->
      </div>
    </div>
    <!--end::Body-->
  </div>
</template>

<script lang="ts">
import { defineComponent } from "vue";
import store from "@/store";
import { Actions } from "@/store/enums/StoreEnums";
import { useI18n } from "vue-i18n";
import { invoices } from "@/core/helpers/invoices";
import { copyLink } from "@/core/helpers/config";
declare const window: any;

export default defineComponent({
  name: "kt-widget-5",
  components: {},
  props: {
    widgetClasses: String,
  },
  setup() {
    const { t, te } = useI18n();

    const translate = (text: string) => {
      if (te(text)) {
        return t(text);
      } else {
        return text;
      }
    };

    store.dispatch(Actions.GET_INVOICES, { top: true });

    return {
      apiDomainName: window.apiDomainName,
      translate,
      invoices,
      copyLink,
    };
  },
});
</script>
